@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 # Get XML.
 has xml => (
@@ -163,7 +163,6 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
  # GraphViz object.
  my $g = Map::Tube::GraphViz->new(
          'callback_node' => \&node_color_without_label,
-         'driver' => 'neato',
          'tube' => $obj,
  );
 
@@ -196,6 +195,7 @@ L<namespace::clean>.
 L<Map::Tube>,
 L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
+L<Map::Tube::Plugin::FuzzyFind>,
 L<Map::Tube::Plugin::Graph>,
 L<Map::Tube::Text::Table>,
 L<Task::Map::Tube>.
@@ -206,10 +206,13 @@ L<Map::Tube::Bucharest>,
 L<Map::Tube::Budapest>,
 L<Map::Tube::Delhi>,
 L<Map::Tube::Dnipropetrovsk>,
+L<Map::Tube::Glasgow>,
 L<Map::Tube::Kazan>,
 L<Map::Tube::Kharkiv>,
 L<Map::Tube::Kiev>,
+L<Map::Tube::KoelnBonn>,
 L<Map::Tube::London>,
+L<Map::Tube::Lyon>,
 L<Map::Tube::Minsk>,
 L<Map::Tube::Moscow>,
 L<Map::Tube::NYC>,
@@ -217,6 +220,7 @@ L<Map::Tube::Nanjing>,
 L<Map::Tube::Novosibirsk>,
 L<Map::Tube::SaintPetersburg>,
 L<Map::Tube::Samara>,
+L<Map::Tube::Singapore>,
 L<Map::Tube::Sofia>,
 L<Map::Tube::Tbilisi>,
 L<Map::Tube::Tokyo>,
@@ -242,6 +246,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.07
+0.08
 
 =cut
